require 'spec_helper'
require 'json'
require 'hashie'

describe 'test response' do
  it 'can create instance' do
    response = ::Facile::Response.new({
      :headers => {},
      :raw_body => 'test'
    })

    expect(response).to be_kind_of(::Facile::Response)
  end

  it 'can read attributes' do
    response = ::Facile::Response.new({
      :headers => {'Foo' => 'bar'},
      :raw_body => 'body'
    })

    expect(response.headers).to eq({'Foo' => 'bar'})
    expect(response.raw_body).to eq('body')
  end

  it 'can create wrappers successfully' do
    body = {'foo' => 'bar'}

    response = ::Facile::Response.new({
      :headers => {'content-type' => 'application/json'},
      :raw_body => JSON.generate(body)
    })

    expect(response.body).to eq(Hashie::Mash.new(body))
  end

  it 'can proxy methods' do
    body = {'foo' => 'bar'}

    response = ::Facile::Response.new({
      :headers => {'content-type' => 'application/json'},
      :raw_body => JSON.generate(body)
    })

    expect(response.body.foo).to eq('bar')
  end

  it 'can mash' do
    body = {'fooZOMG' => 'bar', 'foo' => 1, 'BAR' => 2, 'BaR' => 3}

    mash = ::Facile::Response::Wrapper::Mash.new(body)

    body.keys.each do |key|
      expect(mash.has_key?(key.underscore)).to eq(true)
    end
  end

end
